[rtems-central commit] content: Improve automatically generated warning

Sebastian Huber sebh at rtems.org
Wed Nov 11 07:11:29 UTC 2020


Module:    rtems-central
Branch:    master
Commit:    dd5659abce31e0d8c29b9768a1e9806f9925ae06
Changeset: http://git.rtems.org/rtems-central/commit/?id=dd5659abce31e0d8c29b9768a1e9806f9925ae06

Author:    Sebastian Huber <sebastian.huber at embedded-brains.de>
Date:      Wed Nov 11 08:11:02 2020 +0100

content: Improve automatically generated warning

---

 rtemsspec/content.py                 |  9 +++---
 rtemsspec/tests/test_applconfig.py   | 18 +++++------
 rtemsspec/tests/test_interface.py    |  9 +++---
 rtemsspec/tests/test_interfacedoc.py | 36 +++++++++------------
 rtemsspec/tests/test_specdoc.py      |  9 +++---
 rtemsspec/tests/test_validation.py   | 63 ++++++++++++++++--------------------
 6 files changed, 64 insertions(+), 80 deletions(-)

diff --git a/rtemsspec/content.py b/rtemsspec/content.py
index c9c33d5..7d56dec 100644
--- a/rtemsspec/content.py
+++ b/rtemsspec/content.py
@@ -159,11 +159,10 @@ def _add_context(_content: "Content") -> Iterator[None]:
 _SPECIAL_BLOCK = re.compile(r"^( *\* | *[0-9]+\. | +)")
 
 _AUTOMATICALLY_GENERATED_WARNING = [
-    "Do not manually edit this file.  It is part of the RTEMS quality process",
-    "and was automatically generated.",
-    "",
-    "If you find something that needs to be fixed or worded better please",
-    "post a report to an RTEMS mailing list or raise a bug report:",
+    "This file is part of the RTEMS quality process and was automatically",
+    "generated.  If you find something that needs to be fixed or",
+    "worded better please post a report or patch to an RTEMS mailing list",
+    "or raise a bug report:",
     "",
     "https://docs.rtems.org/branches/master/user/support/bugs.html",
     "",
diff --git a/rtemsspec/tests/test_interface.py b/rtemsspec/tests/test_interface.py
index 636aaf9..924ab32 100644
--- a/rtemsspec/tests/test_interface.py
+++ b/rtemsspec/tests/test_interface.py
@@ -86,11 +86,10 @@ def test_interface(tmpdir):
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
diff --git a/rtemsspec/tests/test_interfacedoc.py b/rtemsspec/tests/test_interfacedoc.py
index 919ac9d..5109478 100644
--- a/rtemsspec/tests/test_interfacedoc.py
+++ b/rtemsspec/tests/test_interfacedoc.py
@@ -56,11 +56,10 @@ def test_interfacedoc(tmpdir):
 
 .. Copyright (C) 2020 embedded brains GmbH (http://www.embedded-brains.de)
 
-.. Do not manually edit this file.  It is part of the RTEMS quality process
-.. and was automatically generated.
-..
-.. If you find something that needs to be fixed or worded better please
-.. post a report to an RTEMS mailing list or raise a bug report:
+.. This file is part of the RTEMS quality process and was automatically
+.. generated.  If you find something that needs to be fixed or
+.. worded better please post a report or patch to an RTEMS mailing list
+.. or raise a bug report:
 ..
 .. https://docs.rtems.org/branches/master/user/support/bugs.html
 ..
@@ -96,11 +95,10 @@ The directives provided by the Group B are:
 
 .. Copyright (C) 2020 embedded brains GmbH (http://www.embedded-brains.de)
 
-.. Do not manually edit this file.  It is part of the RTEMS quality process
-.. and was automatically generated.
-..
-.. If you find something that needs to be fixed or worded better please
-.. post a report to an RTEMS mailing list or raise a bug report:
+.. This file is part of the RTEMS quality process and was automatically
+.. generated.  If you find something that needs to be fixed or
+.. worded better please post a report or patch to an RTEMS mailing list
+.. or raise a bug report:
 ..
 .. https://docs.rtems.org/branches/master/user/support/bugs.html
 ..
@@ -237,11 +235,10 @@ VoidFunction()
 
 .. Copyright (C) 2020 embedded brains GmbH (http://www.embedded-brains.de)
 
-.. Do not manually edit this file.  It is part of the RTEMS quality process
-.. and was automatically generated.
-..
-.. If you find something that needs to be fixed or worded better please
-.. post a report to an RTEMS mailing list or raise a bug report:
+.. This file is part of the RTEMS quality process and was automatically
+.. generated.  If you find something that needs to be fixed or
+.. worded better please post a report or patch to an RTEMS mailing list
+.. or raise a bug report:
 ..
 .. https://docs.rtems.org/branches/master/user/support/bugs.html
 ..
@@ -272,11 +269,10 @@ Group A description. The directives provided by the Group A are:
 
 .. Copyright (C) 2020 embedded brains GmbH (http://www.embedded-brains.de)
 
-.. Do not manually edit this file.  It is part of the RTEMS quality process
-.. and was automatically generated.
-..
-.. If you find something that needs to be fixed or worded better please
-.. post a report to an RTEMS mailing list or raise a bug report:
+.. This file is part of the RTEMS quality process and was automatically
+.. generated.  If you find something that needs to be fixed or
+.. worded better please post a report or patch to an RTEMS mailing list
+.. or raise a bug report:
 ..
 .. https://docs.rtems.org/branches/master/user/support/bugs.html
 ..
diff --git a/rtemsspec/tests/test_specdoc.py b/rtemsspec/tests/test_specdoc.py
index 105d765..393ed8e 100644
--- a/rtemsspec/tests/test_specdoc.py
+++ b/rtemsspec/tests/test_specdoc.py
@@ -66,11 +66,10 @@ def test_document(tmpdir):
 
 .. Copyright (C) 2020 embedded brains GmbH (http://www.embedded-brains.de)
 
-.. Do not manually edit this file.  It is part of the RTEMS quality process
-.. and was automatically generated.
-..
-.. If you find something that needs to be fixed or worded better please
-.. post a report to an RTEMS mailing list or raise a bug report:
+.. This file is part of the RTEMS quality process and was automatically
+.. generated.  If you find something that needs to be fixed or
+.. worded better please post a report or patch to an RTEMS mailing list
+.. or raise a bug report:
 ..
 .. https://docs.rtems.org/branches/master/user/support/bugs.html
 ..
diff --git a/rtemsspec/tests/test_validation.py b/rtemsspec/tests/test_validation.py
index 79eec64..a9e5280 100644
--- a/rtemsspec/tests/test_validation.py
+++ b/rtemsspec/tests/test_validation.py
@@ -78,11 +78,10 @@ def test_validation(tmpdir):
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
@@ -155,11 +154,10 @@ def test_validation(tmpdir):
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
@@ -950,11 +948,10 @@ T_TEST_CASE_FIXTURE( Tc2, &test_case_2_fixture )
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
@@ -1128,11 +1125,10 @@ void Tc6_Run( void )
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
@@ -1215,11 +1211,10 @@ void Tc5_Run( int *a, int b, int *c );
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
@@ -1290,11 +1285,10 @@ void Tc6_Run( void );
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
@@ -1402,11 +1396,10 @@ void Action2_Run( int *a, int b, int *c );
  */
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *



More information about the vc mailing list
diff --git a/rtemsspec/tests/test_applconfig.py b/rtemsspec/tests/test_applconfig.py
index 3a3fca5..3da310c 100644
--- a/rtemsspec/tests/test_applconfig.py
+++ b/rtemsspec/tests/test_applconfig.py
@@ -48,11 +48,10 @@ def test_applconfig(tmpdir):
 
 .. Copyright (C) 2020 embedded brains GmbH (http://www.embedded-brains.de)
 
-.. Do not manually edit this file.  It is part of the RTEMS quality process
-.. and was automatically generated.
-..
-.. If you find something that needs to be fixed or worded better please
-.. post a report to an RTEMS mailing list or raise a bug report:
+.. This file is part of the RTEMS quality process and was automatically
+.. generated.  If you find something that needs to be fixed or
+.. worded better please post a report or patch to an RTEMS mailing list
+.. or raise a bug report:
 ..
 .. https://docs.rtems.org/branches/master/user/support/bugs.html
 ..
@@ -432,11 +431,10 @@ NOTES:
  */
 
 /*
  * Do not manually edit this file.  It is part of the RTEMS quality process
  * and was automatically generated.
  *
  * If you find something that needs to be fixed or worded better please
  * post a report to an RTEMS mailing list or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html
  *
@@ -432,11 +431,10 @@ NOTES:
 
 /*
- * Do not manually edit this file.  It is part of the RTEMS quality process
- * and was automatically generated.
- *
- * If you find something that needs to be fixed or worded better please
- * post a report to an RTEMS mailing list or raise a bug report:
+ * This file is part of the RTEMS quality process and was automatically
+ * generated.  If you find something that needs to be fixed or
+ * worded better please post a report or patch to an RTEMS mailing list
+ * or raise a bug report:
  *
  * https://docs.rtems.org/branches/master/user/support/bugs.html